@@ -16,11 +16,11 @@ typedef struct {
 } OPAnnotation;
 
 OPAnnotationGroup op_annotation_group_new();
-void op_annotation_group_free(OPAnnotationGroup group);
+void op_annotation_group_free(pTHX_ OPAnnotationGroup group);
 OPAnnotation * op_annotation_get(OPAnnotationGroup group, OP *op);
 OPAnnotation * op_annotation_set(OPAnnotationGroup group, OP *op, void *data, OPAnnotationDtor dtor);
-void op_annotation_delete(OPAnnotationGroup table, OP * annotation);
-void op_annotation_free(OPAnnotation *annotation);
+void op_annotation_delete(pTHX_ OPAnnotationGroup table, OP * annotation);
+void op_annotation_free(pTHX_ OPAnnotation *annotation);
 
 END_EXTERN_C
 
